@@ -9,6 +9,7 @@ from __future__ import print_function
 
 __revision__ = "$Id$"
 
+import codecs
 import os.path
 import re
 import sys
@@ -17,8 +18,10 @@ import traceback
 import unittest
 try:
     from cStringIO import StringIO
+    python2 = True
 except ImportError:
     from io import StringIO
+    python2 = False
 from xml.sax.saxutils import escape
 import xml.etree.ElementTree as ET
 
@@ -86,7 +89,7 @@ class _TestInfo(object):
         #        "method": self._method,
         #        "time": self._time,
         #    })
-        stream.write(self._method)
+        stream.write('[Testcase: ' + self._method + ']')
         if self._failure != None:
             stream.write(' ... FAILURE!\n')
             self._print_error_text(stream, 'failure', self._failure)
@@ -159,7 +162,13 @@ class _XMLTestResult(unittest.TestResult):
         self._failure = err
 
     def filter_nonprintable_text(self, text):
-        invalid_chars = re.compile(ur'[^\x09\x0A\x0D\x20-\x7E\x85\xA0-\xFF\u0100-\uD7FF\uE000-\uFDCF\uFDE0-\uFFFD]')
+        pattern = r'[^\x09\x0A\x0D\x20-\x7E\x85\xA0-\xFF\u0100-\uD7FF\uE000-\uFDCF\uFDE0-\uFFFD]'
+        if python2:
+            pattern = pattern.decode('unicode_escape')
+        else:
+            pattern = codecs.decode(pattern, 'unicode_escape')
+        invalid_chars = re.compile(pattern)
+
         def invalid_char_replacer(m):
             return "&#x"+('%04X' % ord(m.group(0)))+";"
         return re.sub(invalid_chars, invalid_char_replacer, str(text))
